Credits
=======

* Carles Sala <csala@csail.mit.edu>
* Micah Smith <micahs@mit.edu>
* Plamen Valentinov <plamen@pythiac.com>
* Laura Gustafson <lgustaf@mit.edu>
* Bennett Cyphers <bennettcyphers@gmail.com>
* Kalyan Veeramachaneni <kalyan@csail.mit.edu>
* Alfredo Cuesta-Infante <alfredo.cuesta@urjc.es>
* Sze Nga Wong <wsnalice@mit.edu>
